@@ -153,7 +153,10 @@ EXPORTED int getxstring(struct protstream *pin, struct protstream *pout,
         buf_reset(buf);
         c = getint32(pin, &len);
 
-        if (pin->isclient && c == '+') {
+        /* For IMAP, LITERAL+ is only valid from client->server.  For MUPDATE
+         * it's valid in either direction.
+         */
+        if ((pin->isclient || (flags & GXS_MUPDATE)) && c == '+') {
             /* LITERAL- says maximum size is 4096! */
             if (lminus && len > 4096) {
                 /* Fail per RFC 7888, Section 4, choice 2 */
